<?xml version="1.0" encoding="UTF-8"?>
<!-- FZ821v1.1_VALXSLT_476u1, 28-07-2021 -->
<xsl:stylesheet version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
 xmlns:vbt="http://ei.vektis.nl/fz/basis/v1_1"
 xmlns:fz821="http://ei.vektis.nl/fz/fz821_476/v1_1"
 xmlns:fz822="http://ei.vektis.nl/fz/fz822_477/v1_1">
 
 
	<xsl:import href="rc8028.xslt"/>
	<xsl:import href="rc8986.xslt"/>
	<xsl:import href="rc0350.xslt"/>
	<xsl:import href="rc0350a.xslt"/>
	<xsl:import href="rc9169.xslt"/>
	<xsl:import href="rc8914.xslt"/>
	<xsl:import href="rc9170.xslt"/>
	<xsl:import href="rc9171.xslt"/>
	<xsl:import href="rc9172.xslt"/>
	<xsl:import href="rc9173.xslt"/>
	<xsl:import href="rc9174.xslt"/>
	<xsl:import href="rc9182.xslt"/>
	<xsl:import href="rc9463.xslt"/>
	
	<!-- Uitvoer is fz822 bericht met Retourcodes. -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	
	<xsl:variable name="BerichtSoort" select="//fz821:Bericht/fz821:Header/vbt:BerichtSoort"/>
	<xsl:variable name="Verzenddatum" select="translate(//fz821:Bericht/fz821:Header/vbt:Verzenddatum, '-', '')"/>
	<xsl:template match="//fz821:Bericht">
		<fz822:Bericht>
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/fz/fz822_477/v1_1 fz822_477.xsd</xsl:attribute>
			<!-- Controleer op errors in de Header -->
			<!-- retourcode 8028: Soort bericht ontbreekt of is onjuist -->
			<xsl:variable name="rc8028">
				<xsl:call-template name="rc8028">
					<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
				</xsl:call-template>
			</xsl:variable>
			<!-- retourcode 8986: Verzenddatum moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
			<xsl:variable name="rc8986">
				<xsl:call-template name="rc8986">
					<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
					<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:choose>
				<!-- Geen errors in de Header, dan hele bericht als retour -->
				<xsl:when test="$rc8028='' and $rc8986=''">
					<xsl:apply-templates select="fz821:Header"/>
					<xsl:apply-templates select="fz821:Verzekerde"/>
				</xsl:when>
				<!-- Wel errors in de Header, dan alleen Header als retour -->
				<xsl:otherwise>
					<xsl:apply-templates select="fz821:Header"/>
				</xsl:otherwise>
			</xsl:choose>
		</fz822:Bericht>
	</xsl:template>
	<xsl:template match="fz821:Header">
		<fz822:Header>
			<xsl:apply-templates select="vbt:BerichtSoort" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Verzenddatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:AfzenderReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz821:JustitieleInstantie"/>
			<xsl:apply-templates select="fz821:Zorgaanbieder"/>
			<fz822:BerichtCode>477</fz822:BerichtCode>
			<xsl:apply-templates select="fz821:BerichtVersie" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz821:BerichtSubVersie" mode="copy-if-exists"/>
			<fz822:Afwijsgrond>01</fz822:Afwijsgrond>
			<fz822:Retourcodes>
				<!-- retourcode 8028: Soort bericht ontbreekt of is onjuist -->
				<xsl:variable name="rc8028">
					<xsl:call-template name="rc8028">
						<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
					</xsl:call-template>
				</xsl:variable>
				<!-- retourcode 8920: Verzenddatum moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
				<xsl:variable name="rc8986">
					<xsl:call-template name="rc8986">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
						<xsl:with-param name="BerichtSoort" select="$BerichtSoort"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:copy-of select="$rc8028"/>
				<xsl:copy-of select="$rc8986"/>
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc8028='' and $rc8986=''">
					<vbt:Retourcode>0200</vbt:Retourcode>
				</xsl:if>
			</fz822:Retourcodes>
		</fz822:Header>
	</xsl:template>
	<xsl:template match="fz821:Verzekerde">
		<fz822:Verzekerde>
			<xsl:apply-templates select="vbt:Verzekerdennummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Geboortedatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:GeboortedatumOnbekend" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam"/>
			<xsl:apply-templates select="vbt:NaamcodeNaamgebruik" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Voorletters" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Voornamen" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:GeslachtCode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Geboorteplaats" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Identiteitsdocument"/>
			<xsl:apply-templates select="fz821:Verblijfplaats"/>
			<xsl:apply-templates select="fz821:GBAadres"/>
			<xsl:apply-templates select="fz821:ForensischeZorgtitel"/>
			<xsl:apply-templates select="fz821:Indicatie"/>
			<xsl:apply-templates select="fz821:Aanmelding"/>
			<fz822:Retourcodes>
				<!-- retourcode 0350a: Geboortedatum moet kleiner zijn dan verzenddatum -->
				<xsl:variable name="rc0350">
					<xsl:call-template name="rc0350">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
						<xsl:with-param name="Geboortedatum" select="translate(//fz821:Bericht/fz821:Verzekerde/vbt:Geboortedatum, '-', '')"/>
					</xsl:call-template>
				</xsl:variable>
				<!-- retourcode 0350b: Geboortedatum moet bestaan als GeboortdatumOnbekend = "false" -->
				<xsl:variable name="rc0350a">
					<xsl:call-template name="rc0350a">
						<xsl:with-param name="GeboortedatumOnbekend" select="//fz821:Bericht/fz821:Verzekerde/vbt:GeboortedatumOnbekend"/>
						<xsl:with-param name="Geboortedatum" select="translate(//fz821:Bericht/fz821:Verzekerde/vbt:Geboortedatum, '-', '')"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:copy-of select="$rc0350"/>
				<xsl:copy-of select="$rc0350a"/>
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc0350='' and $rc0350a=''">
					<vbt:Retourcode>0200</vbt:Retourcode>
				</xsl:if>
			</fz822:Retourcodes>
		</fz822:Verzekerde>
	</xsl:template>
	<xsl:template match="fz821:Aanmelding">
		<fz822:Aanmelding>
			<xsl:apply-templates select="vbt:Aanmeldingsnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Aanmeldingsvolgnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Status" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:BeoogdeStartdatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:IndicatieBijzondereVoorwaarden" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:JuridischeStatus" mode="copy-if-exists"/>
			<vbt:Retourcodes>
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
					<vbt:Retourcode>0200</vbt:Retourcode>
			</vbt:Retourcodes>
		</fz822:Aanmelding>
	</xsl:template>
	<xsl:template match="fz821:ForensischeZorgtitel">
		<fz822:ForensischeZorgtitel>
			<xsl:apply-templates select="vbt:ForensischeZorgtitelNummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:ForensischeZorgtitelStartdatumOnbekend" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:ForensischeZorgtitelPeriode"/>
			<xsl:apply-templates select="vbt:Parketnummer" mode="copy-if-exists"/>
			<vbt:Retourcodes>
				<!-- retourcode 9169: Einddatum Forensische Zorgtitel moet groter zijn dan of gelijk zijn aan startdatum Forensische Zorgtitel. -->
				<xsl:variable name="rc9169">
					<xsl:call-template name="rc9169">
						<xsl:with-param name="Startdatum" select="translate(//fz821:Bericht/fz821:Verzekerde/fz821:ForensischeZorgtitel/vbt:ForensischeZorgtitelPeriode/vbt:Startdatum, '-', '')"/>
						<xsl:with-param name="Einddatum" select="translate(//fz821:Bericht/fz821:Verzekerde/fz821:ForensischeZorgtitel/vbt:ForensischeZorgtitelPeriode/vbt:Einddatum, '-', '')"/>
					</xsl:call-template>
				</xsl:variable>

				<!-- retourcode 9463: Indien ForensischeZorgtitelStartdatumOnbekend heeft waarde ‘false’, dan moet ForensischeZorgtitelPeriode/Startdatum voorkomen.-->
				<xsl:variable name="rc9463">
					<xsl:call-template name="rc9463">
						<xsl:with-param name="ForensischeZorgtitelStartdatumOnbekend" select="//fz821:Bericht/fz821:Verzekerde/fz821:ForensischeZorgtitel/vbt:ForensischeZorgtitelStartdatumOnbekend"/>
						<xsl:with-param name="Startdatum" select="translate(//fz821:Bericht/fz821:Verzekerde/fz821:ForensischeZorgtitel/vbt:ForensischeZorgtitelPeriode/vbt:Startdatum, '-', '')"/>
					</xsl:call-template>
				</xsl:variable>

				<xsl:copy-of select="$rc9169"/>
				<xsl:copy-of select="$rc9463"/>

				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc9169='' and $rc9463=''">
					<vbt:Retourcode>0200</vbt:Retourcode>
				</xsl:if>
			</vbt:Retourcodes>
		</fz822:ForensischeZorgtitel>
	</xsl:template>
	<xsl:template match="vbt:ForensischeZorgtitelPeriode">
		<vbt:ForensischeZorgtitelPeriode>
			<xsl:apply-templates select="vbt:Startdatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Einddatum" mode="copy-if-exists"/>
		</vbt:ForensischeZorgtitelPeriode>
	</xsl:template>
	<xsl:template match="fz821:Indicatie">
		<fz822:Indicatie>
			<xsl:apply-templates select="vbt:Indicatiebesluitnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:AfgiftedatumIndicatiebesluit" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:GeindiceerdeZorgsetting"/>
			<vbt:Retourcodes>
				<!-- retourcode 8914: Datum afgifte indicatiebesluit moet kleiner zijn dan of gelijk zijn aan dagtekening aanmaak.-->
				<xsl:variable name="rc8914">
					<xsl:call-template name="rc8914">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
						<xsl:with-param name="AfgiftedatumIndicatiebesluit" select="translate(//fz821:Bericht/fz821:Verzekerde/fz821:Indicatie/vbt:AfgiftedatumIndicatiebesluit, '-', '')"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:copy-of select="$rc8914"/>
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc8914=''">
					<vbt:Retourcode>0200</vbt:Retourcode>
				</xsl:if>
			</vbt:Retourcodes>
			<xsl:apply-templates select="fz821:Delicten"/>
		</fz822:Indicatie>
	</xsl:template>
	<xsl:template match="vbt:GeindiceerdeZorgsetting">
		<vbt:GeindiceerdeZorgsetting>
			<xsl:apply-templates select="vbt:CodeZorgType" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:BeveiligingsniveauCode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:CodeVerblijfsintensiteitCombinatie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:CodeZZPCCombinatie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:CodeZZPVGCombinatie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:CodeAmbulanteZorgCombinatie" mode="copy-if-exists"/>
			<vbt:Retourcodes>
				<xsl:variable name="CodeZorgType" select="//fz821:Bericht/fz821:Verzekerde/fz821:Indicatie/vbt:GeindiceerdeZorgsetting/vbt:CodeZorgType"/>
				<!-- retourcode 9170 BeveiligingsniveauCode moet voorkomen bij deze waarde in CodeZorgtype.-->
				<xsl:variable name="rc9170">
					<xsl:call-template name="rc9170">
						<xsl:with-param name="CodeZorgType" select="$CodeZorgType"/>
						<xsl:with-param name="BeveiligingsniveauCode" select="//fz821:Bericht/fz821:Verzekerde/fz821:Indicatie/vbt:GeindiceerdeZorgsetting/vbt:BeveiligingsniveauCode"/>
					</xsl:call-template>
				</xsl:variable>
				<!-- retourcode 9171 CodeVerblijfsintensiteitCombinatie moet voorkomen bij deze waarde in CodeZorgtype.-->
				<xsl:variable name="rc9171">
					<xsl:call-template name="rc9171">
						<xsl:with-param name="CodeZorgType" select="$CodeZorgType"/>
						<xsl:with-param name="CodeVerblijfsintensiteitCombinatie" select="//fz821:Bericht/fz821:Verzekerde/fz821:Indicatie/vbt:GeindiceerdeZorgsetting/vbt:CodeVerblijfsintensiteitCombinatie"/>
					</xsl:call-template>
				</xsl:variable>
				<!-- retourcode 9172 CodeZZPCCombinatie of CodeZZPVGCombinatie moet voorkomen bij deze waarde in CodeZorgtype.-->
				<xsl:variable name="rc9172">
					<xsl:call-template name="rc9172">
						<xsl:with-param name="CodeZorgType" select="$CodeZorgType"/>
						<xsl:with-param name="CodeZZPCCombinatie" select="//fz821:Bericht/fz821:Verzekerde/fz821:Indicatie/vbt:GeindiceerdeZorgsetting/vbt:CodeZZPCCombinatie"/>
						<xsl:with-param name="CodeZZPVGCombinatie" select="//fz821:Bericht/fz821:Verzekerde/fz821:Indicatie/vbt:GeindiceerdeZorgsetting/vbt:CodeZZPVGCombinatie"/>
					</xsl:call-template>
				</xsl:variable>
				<!-- retourcode 9173 CodeZZPCCombinatie of CodeZZPVGCombinatie mogen niet beide voorkomen bij deze waarde in CodeZorgtype.-->
				<xsl:variable name="rc9173">
					<xsl:call-template name="rc9173">
						<xsl:with-param name="CodeZorgType" select="$CodeZorgType"/>
						<xsl:with-param name="CodeZZPCCombinatie" select="//fz821:Bericht/fz821:Verzekerde/fz821:Indicatie/vbt:GeindiceerdeZorgsetting/vbt:CodeZZPCCombinatie"/>
						<xsl:with-param name="CodeZZPVGCombinatie" select="//fz821:Bericht/fz821:Verzekerde/fz821:Indicatie/vbt:GeindiceerdeZorgsetting/vbt:CodeZZPVGCombinatie"/>
					</xsl:call-template>
				</xsl:variable>
				<!-- retourcode 9174 CodeAmbulanteZorgCombinatie moet met waarde 07 voorkomen bij deze waarde in CodeZorgtype.-->
				<xsl:variable name="rc9174">
					<xsl:call-template name="rc9174">
						<xsl:with-param name="CodeZorgType" select="$CodeZorgType"/>
						<xsl:with-param name="CodeAmbulanteZorgCombinatie" select="//fz821:Bericht/fz821:Verzekerde/fz821:Indicatie/vbt:GeindiceerdeZorgsetting/vbt:CodeAmbulanteZorgCombinatie"/>
					</xsl:call-template>
				</xsl:variable>
				<!-- retourcode 9182 CodeZZPCCombinatie of CodeZZPVGCombinatie mogen niet beide voorkomen bij deze waarde in CodeZorgtype.-->
				<xsl:variable name="rc9182">
					<xsl:call-template name="rc9182">
						<xsl:with-param name="CodeZorgType" select="$CodeZorgType"/>
						<xsl:with-param name="CodeAmbulanteZorgCombinatie" select="//fz821:Bericht/fz821:Verzekerde/fz821:Indicatie/vbt:GeindiceerdeZorgsetting/vbt:CodeAmbulanteZorgCombinatie"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:copy-of select="$rc9170"/>
				<xsl:copy-of select="$rc9171"/>
				<xsl:copy-of select="$rc9172"/>
				<xsl:copy-of select="$rc9173"/>
				<xsl:copy-of select="$rc9174"/>
				<xsl:copy-of select="$rc9182"/>
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc9170='' and $rc9171=''  and $rc9172='' and $rc9173='' and $rc9174='' and $rc9182=''">
					<vbt:Retourcode>0200</vbt:Retourcode>
				</xsl:if>
			</vbt:Retourcodes>
		</vbt:GeindiceerdeZorgsetting>
	</xsl:template>
	<xsl:template match="fz821:Delicten">
		<fz822:Delicten>
			<xsl:apply-templates select="vbt:Delict" mode="copy-if-exists"/>
		</fz822:Delicten>
	</xsl:template>
	<xsl:template match="fz821:JustitieleInstantie">
		<fz822:JustitieleInstantie>
			<xsl:apply-templates select="vbt:UZOVINummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:InstantieCode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam"/>
			<xsl:apply-templates select="vbt:Voorletters" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Emailadres" mode="copy-if-exists"/>
		</fz822:JustitieleInstantie>
	</xsl:template>
	<xsl:template match="fz821:Zorgaanbieder">
		<fz822:Zorgaanbieder>
			<xsl:apply-templates select="vbt:Ondernemingscode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Vestigingscode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Emailadres" mode="copy-if-exists"/>
		</fz822:Zorgaanbieder>
	</xsl:template>
	<xsl:template match="vbt:Naam">
		<vbt:Naam>
			<xsl:apply-templates select="vbt:Achternaam" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Voorvoegsels" mode="copy-if-exists"/>
		</vbt:Naam>
	</xsl:template>
	<xsl:template match="vbt:Identiteitsdocument">
		<vbt:Identiteitsdocument>
			<xsl:apply-templates select="vbt:Type" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Nummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Geldigheidsdatum" mode="copy-if-exists"/>
		</vbt:Identiteitsdocument>
	</xsl:template>
	<xsl:template match="fz821:Verblijfplaats">
		<fz822:Verblijfplaats>
			<xsl:apply-templates select="vbt:Straatnaam" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Huisnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:HuisnummerToevoeging" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Postcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Plaatsnaam" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Telefoonnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:AdresSoort" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Instellingsnaam" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Afdelingsnaam" mode="copy-if-exists"/>
		</fz822:Verblijfplaats>
	</xsl:template>
	<xsl:template match="fz821:GBAadres">
		<fz822:GBAadres>
			<xsl:apply-templates select="vbt:Straatnaam" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Huisnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:HuisnummerToevoeging" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Postcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Plaatsnaam" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Telefoonnummer" mode="copy-if-exists"/>
		</fz822:GBAadres>
	</xsl:template>
	<!-- Copy template: als een enkel element voorkomt is, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="*[namespace-uri()='http://ei.vektis.nl/fz/fz821_476/v1_1']" mode="copy-if-exists">
		<xsl:if test=".">
			<xsl:element name="{concat('fz822:',local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template match="*[namespace-uri()='http://ei.vektis.nl/fz/basis/v1_1']" mode="copy-if-exists">
		<xsl:if test=".">
			<xsl:element name="{concat('vbt:',local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
